==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/ru.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Журналирование",
    "Errors in the log" : "Ошибки в журнале",
    "Failed to get an iterator for log entries: %s" : "Не удалось получить итератор для записей журнала: %s",
    "No errors in the logs since %s" : "Журнал не содержит записей об произошедших ошибках начиная с %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["Журнал содержит %n запись об произошедших ошибках начиная с %s","Журнал содержит %n записи об произошедших ошибках начиная с %s","Журнал содержит %n записей об произошедших ошибках начиная с %s","Журнал содержит %n записи об произошедших ошибках начиная с %s"],
    "Log Reader" : "Просмотр журналов",
    "A log reader for Nextcloud" : "Просмотр журналов(логов) для Nextcloud",
    "Log reader for Nextcloud" : "Просмотр журналов(логов) для Nextcloud",
    "Log reader" : "Просмотрщик журнала",
    "Open log reader settings" : "Открыть параметры просмоторщика журнала",
    "Log reader settings" : "Параметры просмоторщика журнала",
    "Currently the log file {file} is shown" : "В данный момент отображается файл журнала {file}",
    "Show server log" : "Показать журнал сервера",
    "Live view is disabled" : "Живой просмотр отключен",
    "No log file" : "Отсутствует файл журнала",
    "File-based logging must be enabled to access logs from the Web UI." : "Для доступа к журналам из веб-интерфейса необходимо включить ведение журнала на основе файлов.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Если вы считаете, что это ошибка, пожалуйста, проверьте {setting} в вашей {config} и ознакомьтесь с руководством по администрированию Nextcloud.",
    "Level" : "Уровень",
    "App" : "Приложение",
    "No app in context" : "Нет приложения в контексте",
    "Time" : "Время",
    "Copy raw entry" : "Скопировать необработанную запись",
    "Copy formatted entry" : "Скопировать отформатированную запись",
    "Hide exception details" : "Скрыть сведения об исключении",
    "View exception details" : "Показать сведения об исключении",
    "Raw log entry" : "Необработанная запись в журнале",
    "Log entry successfully copied" : "Запись в журнале успешно скопирована",
    "Search log entries" : "Поиск записей в журнале",
    "Caused by {exception}" : "Вызвано {exception}",
    "Line {line}" : "Линия {line}",
    "Filter log levels" : "Фильтр по уровню логирования",
    "Set log level" : "Установить уровень ведения журнала",
    "Time format" : "Формат времени",
    "Live view" : "Просмотр в реальном времени",
    "Download/Upload logs" : "Загрузка/выгрузка журналов",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Вы также можете отобразить записи журнала, скопированные из буфера обмена, вставив их в окно просмотра журнала с помощью: {keyboardShortcut}",
    "Download logs" : "Скачать журналы",
    "Show local log file" : "Показать локальный файл журнала",
    "Upload local log file to be displayed" : "Загрузите локальный файл журнала для отображения",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Не удалось проанализировать локальный файл журнала",
    "Raw data" : "Сырые данные",
    "Local time" : "Местное время",
    "UTC time" : "Всемирное координированное время",
    "Relative" : "Относительно",
    "Time format used for displaying the timestamp" : "Формат времени, используемый для отображения временной метки",
    "(Local log files only support the \"raw\" time format)" : "(Локальные файлы журналов поддерживают только \"необработанный\" формат времени)",
    "Could not change date time format." : "Не удалось изменить формат даты и времени.",
    "Polling is disabled because server is not configured to log to file" : "Опрос отключен, поскольку сервер не настроен для логирования в файл",
    "Polling (live view)" : "Опрос (просмотр в режиме реального времени)",
    "Could not change live view setting." : "Не удалось изменить настройки просмотра в реальном времени.",
    "Filter logging levels" : "Фильтровать по уровню логирования",
    "Could not set logging levels to show" : "Не удалось установить уровни логирования для отображения",
    "Set backend loglevel" : "Установить уровень внутреннего журнала",
    "Could not set logging level" : "Не удалось установить уровень ведения журнала",
    "Application" : "Приложение",
    "Message" : "Сообщение",
    "Log entry actions" : "Действия по записи в журнал",
    "Loading older log entries" : "Загрузка старых записей журнала",
    "No older log entries available" : "Более старые записи журнала недоступны",
    "Collapse row" : "Свернуть строку",
    "Expand row" : "Развернуть строку",
    "Show details" : "Подробные сведения",
    "Debug" : "Отладка",
    "Info" : "Информация",
    "Warning" : "Предупреждение",
    "Error" : "Ошибка",
    "Fatal" : "Критическая ошибка",
    "Could not load log entries" : "Не удалось загрузить записи журнала.",
    "Clipboard" : "Буфер обмена",
    "Could not parse clipboard content" : "Не удалось проанализировать содержимое буфера обмена",
    "Could not fetch new log entries (server unavailable)" : "Не удалось получить новые записи журнала (сервер недоступен)",
    "Could not fetch new entries" : "Не удалось получить новые записи",
    "Could not copy to clipboard, please copy manually:" : "Не удалось скопировать в буфер обмена, пожалуйста, скопируйте вручную:",
    "\tfrom {address} by {user} at {time}\n" : "\tна {address} от {user} в {time}\n"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-30.0.13.tgz: nextcloud/apps/logreader/l10n/ru.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Системный журнал",
    "Errors in the log" : "Ошибки в журнале",
    "Failed to get an iterator for log entries: %s" : "Не удалось получить итератор для записей журнала: %s",
    "No errors in the logs since %s" : "Журнал не содержит записей об произошедших ошибках начиная с %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["Журнал содержит %n запись об произошедших ошибках начиная с %s","Журнал содержит %n записи об произошедших ошибках начиная с %s","Журнал содержит %n записей об произошедших ошибках начиная с %s","Журнал содержит %n записи об произошедших ошибках начиная с %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n предупреждение в журнале с %s","%n предупреждения в журнале с %s","%n предупреждений в журнале с %s","%n предупреждений в журнале с %s"],
    "Log Reader" : "Просмотр журналов",
    "A log reader for Nextcloud" : "Просмотр журналов(логов) для Nextcloud",
    "Log reader for Nextcloud" : "Просмотр журналов(логов) для Nextcloud",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Если вы считаете, что это ошибка, пожалуйста, проверьте {setting} в вашей {config} и ознакомьтесь с руководством по администрированию Nextcloud.",
    "Log reader" : "Просмотрщик журнала",
    "Open log reader settings" : "Открыть параметры просмоторщика журнала",
    "Log reader settings" : "Параметры просмоторщика журнала",
    "Currently the log file {file} is shown" : "В данный момент отображается файл журнала {file}",
    "Show server log" : "Показать журнал сервера",
    "Live view is disabled" : "Живой просмотр отключен",
    "No log file" : "Отсутствует файл журнала",
    "File-based logging must be enabled to access logs from the Web UI." : "Для доступа к журналам из веб-интерфейса необходимо включить ведение журнала на основе файлов.",
    "Log entry successfully copied" : "Запись в журнале успешно скопирована",
    "Level" : "Уровень",
    "App" : "Приложение",
    "No app in context" : "Нет приложения в контексте",
    "Time" : "Время",
    "Copy raw entry" : "Скопировать необработанную запись",
    "Copy formatted entry" : "Скопировать отформатированную запись",
    "Hide exception details" : "Скрыть сведения об исключении",
    "View exception details" : "Показать сведения об исключении",
    "Raw log entry" : "Необработанная запись в журнале",
    "Search log entries" : "Поиск записей в журнале",
    "Caused by {exception}" : "Вызвано {exception}",
    "Line {line}" : "Линия {line}",
    "Filter log levels" : "Фильтр по уровню логирования",
    "Set log level" : "Установить уровень ведения журнала",
    "Time format" : "Формат времени",
    "Live view" : "Просмотр в реальном времени",
    "Download/Upload logs" : "Загрузка/выгрузка журналов",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Не удалось проанализировать локальный файл журнала",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Вы также можете отобразить записи журнала, скопированные из буфера обмена, вставив их в окно просмотра журнала с помощью: {keyboardShortcut}",
    "Download logs" : "Скачать журналы",
    "Show local log file" : "Показать локальный файл журнала",
    "Upload local log file to be displayed" : "Загрузите локальный файл журнала для отображения",
    "Time format used for displaying the timestamp" : "Формат времени, используемый для отображения временной метки",
    "(Local log files only support the \"raw\" time format)" : "(Локальные файлы журналов поддерживают только \"необработанный\" формат времени)",
    "Could not change date time format." : "Не удалось изменить формат даты и времени.",
    "Raw data" : "Сырые данные",
    "Local time" : "Местное время",
    "UTC time" : "Всемирное координированное время",
    "Relative" : "Относительно",
    "Could not change live view setting." : "Не удалось изменить настройки просмотра в реальном времени.",
    "Polling is disabled because server is not configured to log to file" : "Опрос отключен, поскольку сервер не настроен для логирования в файл",
    "Polling (live view)" : "Опрос (просмотр в режиме реального времени)",
    "Could not set logging levels to show" : "Не удалось установить уровни логирования для отображения",
    "Filter logging levels" : "Фильтровать по уровню логирования",
    "Could not set logging level" : "Не удалось установить уровень ведения журнала",
    "Set backend loglevel" : "Установить уровень внутреннего журнала",
    "Application" : "Приложение",
    "Message" : "Сообщение",
    "Log entry actions" : "Действия по записи в журнал",
    "Loading older log entries" : "Загрузка старых записей журнала",
    "No older log entries available" : "Более старые записи журнала недоступны",
    "Collapse row" : "Свернуть строку",
    "Expand row" : "Развернуть строку",
    "Show details" : "Подробные сведения",
    "Debug" : "Отладка",
    "Info" : "Информация",
    "Warning" : "Предупреждение",
    "Error" : "Ошибка",
    "Fatal" : "Критическая ошибка",
    "Could not load log entries" : "Не удалось загрузить записи журнала.",
    "Clipboard" : "Буфер обмена",
    "Could not parse clipboard content" : "Не удалось проанализировать содержимое буфера обмена",
    "Could not fetch new log entries (server unavailable)" : "Не удалось получить новые записи журнала (сервер недоступен)",
    "Could not fetch new entries" : "Не удалось получить новые записи",
    "Could not copy to clipboard, please copy manually:" : "Не удалось скопировать в буфер обмена, пожалуйста, скопируйте вручную:",
    "\tfrom {address} by {user} at {time}\n" : "\tна {address} от {user} в {time}\n"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
